@@ -6,6 +6,11 @@ def node_decorator(*args, **kwargs):
         class NewCls(cls):
             def __init__(self):
                 self.cls = cls
+                self.color = ''
+                self.icon = ''
+                self.editor = None
+                self.inputs = 1
+                self.outputs = 1
 
             def __getattribute__(self, s):
                 if s in kwargs:
