@@ -8,4 +8,4 @@ class NodeFactory:
     def on_create(self, config: bytes):
         node = Runtime.deserialize(config, self.c)
         Runtime.add_node(node.guid, node)
-        node.on_create(config)
+        node.on_create()
