@@ -1,6 +1,6 @@
 import inspect, json, sys
 from robomotion.node import Node
-from variable import Variable, InVariable, OptVariable, OutVariable, Credentials, ECategory, _Enum
+from robomotion.variable import Variable, InVariable, OptVariable, OutVariable, Credentials, ECategory, _Enum
 
 
 class NodeSpec:
