@@ -1,4 +1,4 @@
-from runtime import Runtime
+from robomotion.runtime import Runtime
 from robomotion import plugin_pb2
 from google.protobuf import json_format
 from robomotion.struct_pb2 import Struct
